def sing():
    print("Bibi, bibi, bibi Cammello\n"\
          "Aveva una gobba proprio come un Cammello\n"\
          "Bibi, bibi, bibi Cammello\n"\
          "Andava sempre in giro con il suo ombrello\n"
          )






"""  Created on 09/06/2023::
------------- __about__.py -------------

**Authors**: L. Mingarelli
"""

__about__ = "A singing Cammello."
__version__= '0.0.1'
__author__ = 'Luca Mingarelli'
__email__ = "lucamingarelli@me.com"
__url__ = "https://github.com/LucaMingarelli/cammello"



"""  Created on 26/05/2023::
------------- setup.py -------------

**Authors**: L. Mingarelli
"""

import setuptools
from cammello.__about__ import (__about__, __author__, __email__, __version__, __url__)

with open("README.md", 'r') as f:
    long_description = f.read()


setuptools.setup(
    name="cammello",
    version=__version__,
    author=__author__,
    author_email=__email__,
    description=__about__,
    url=__url__,
    license='MIT',
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=['cammello', 'cammello.res'],
    package_data={'':  ['../cammello/res/*']},
    classifiers=["Programming Language :: Python :: 3",
                 "License :: OSI Approved :: MIT License",
                 "Operating System :: OS Independent"],
    python_requires='>=3.6',
)




